.. code-block::
  
	 ______   __  __    ______    __   __    ______    __     __    
	/\  == \ /\ \_\ \  /\  ___\  /\ "-.\ \  /\  __ \  /\ \  _ \ \   
	\ \  _-/ \ \____ \ \ \___  \ \ \ \-.  \ \ \ \/\ \ \ \ \/ ".\ \  
	 \ \_\    \/\_____\ \/\_____\ \ \_\\"\_\ \ \_____\ \ \__/".~\_\ 
	  \/_/     \/_____/  \/_____/  \/_/ \/_/  \/_____/  \/_/   \/_/ 
			- a Python library for the ServiceNow REST API
			
.. image:: https://travis-ci.org/rbw0/pysnow.svg?branch=master
    :target: https://travis-ci.org/rbw0/pysnow
.. image:: https://coveralls.io/repos/github/rbw0/pysnow/badge.svg?branch=master
    :target: https://coveralls.io/github/rbw0/pysnow?branch=master
.. image:: https://badge.fury.io/py/pysnow.svg
    :target: https://pypi.python.org/pypi/pysnow
    
Installation
------------
# pip install pysnow


Usage examples
--------------
Go `here <http://pysnow.readthedocs.io/en/latest/usage>`_ for usage examples


Documentation
-------------
The full documentation is available `here <http://pysnow.readthedocs.org/>`_


Compatibility
-------------
Python 2 and 3. Tested: Python 2.6+ and Python 3.3+

Contributors
------------
lingfish, jcpunk, AMMullan, amontalban, ryancurrah, jdugan1024, punkrokk


JetBrains
---------
Thank you Jetbrains (www.jetbrains.com) for supporting with IDE licenses!

Author
------
Created by Robert Wikman <rbw@vault13.org> in 2016

